@@ -14,7 +14,7 @@ use chrono::{Local, DateTime};
 use clap::{App, AppSettings, Arg, ArgGroup};
 use util::{option, validator, sys, handler};
 
-const CRATE_UPDATE_DATE: &str = "2021-05-08";
+const CRATE_UPDATE_DATE: &str = "2021-06-26";
 const CRATE_AUTHOR_GITHUB: &str = "shellrow <https://github.com/shellrow>";
 const CRATE_REPOSITORY: &str = "https://github.com/shellrow/nscan";
 
@@ -74,6 +74,9 @@ fn main() {
             if let Some(s) = matches.value_of("save") {
                 opt.set_save_path(s.to_string());
             }
+            if matches.is_present("multithread") {
+                opt.set_multi_thread_enabled(true);
+            }
             handler::handle_port_scan(opt);
         }
     }else if matches.is_present("host") {
@@ -129,6 +132,12 @@ fn get_app_settings<'a, 'b>() -> App<'a, 'b> {
             .value_name("ip_addr")
             .validator(validator::validate_host_opt)
         )
+        .arg(Arg::with_name("multithread")
+            .help("Run port scan in multi-thread (default is single-thread)")
+            .short("m")
+            .long("multithread")
+            .takes_value(false)
+        )
         .arg(Arg::with_name("timeout")
             .help("Set timeout in ms - Ex: -t 10000")
             .short("t")
